@@ -1,4 +1,4 @@
-use yansi::Color;
+use yansi::{Color, Paint};
 
 /// Print a warning to stderr. If `enable_styles` is true, then a yellow
 /// message will be printed.
@@ -14,7 +14,7 @@ pub fn print_error(enable_styles: bool, error: &anyhow::Error) {
 
 fn print_msg(enable_styles: bool, message: &str, prefix: &'static str, color: Color) {
     if enable_styles {
-        eprintln!("{}{}", color.paint(prefix), color.paint(message));
+        eprintln!("{}{}", prefix.paint(color), message.paint(color));
     } else {
         eprintln!("{message}");
     }
